summaryrefslogtreecommitdiffstats
path: root/extensions/common/extension.h
diff options
context:
space:
mode:
authorscheib@chromium.org <scheib@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-09 17:03:05 +0000
committerscheib@chromium.org <scheib@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-09 17:03:05 +0000
commitf8e46614369594c29c72b0ae1a4b53ad259ed4af (patch)
treecbc40ffedb2a18b0c7f4d664dfbe80f031d923c8 /extensions/common/extension.h
parent68e301f49a64e5fa5cce8cb3a8dd6e6ffbfcc173 (diff)
downloadchromium_src-f8e46614369594c29c72b0ae1a4b53ad259ed4af.zip
chromium_src-f8e46614369594c29c72b0ae1a4b53ad259ed4af.tar.gz
chromium_src-f8e46614369594c29c72b0ae1a4b53ad259ed4af.tar.bz2
Unload all apps / extensions immediately when deleting a profile.
Previously apps could remain running with references to profiles that had been deleted by users, but before the browser shut down and profiles were fully removed. Problems included E.g. opening a link in an app would open a tab in the deleted profile. BUG=368684 TEST=Manual testing as described on http://crbug.com/368684#c1 Review URL: https://codereview.chromium.org/266343002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@269343 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'extensions/common/extension.h')
-rw-r--r--extensions/common/extension.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/extensions/common/extension.h b/extensions/common/extension.h
index 10df63c..0d01dd2 100644
--- a/extensions/common/extension.h
+++ b/extensions/common/extension.h
@@ -514,11 +514,13 @@ struct InstalledExtensionInfo {
struct UnloadedExtensionInfo {
// TODO(DHNishi): Move this enum to ExtensionRegistryObserver.
enum Reason {
- REASON_DISABLE, // Extension is being disabled.
- REASON_UPDATE, // Extension is being updated to a newer version.
- REASON_UNINSTALL, // Extension is being uninstalled.
- REASON_TERMINATE, // Extension has terminated.
- REASON_BLACKLIST, // Extension has been blacklisted.
+ REASON_UNDEFINED, // Undefined state used to initialize variables.
+ REASON_DISABLE, // Extension is being disabled.
+ REASON_UPDATE, // Extension is being updated to a newer version.
+ REASON_UNINSTALL, // Extension is being uninstalled.
+ REASON_TERMINATE, // Extension has terminated.
+ REASON_BLACKLIST, // Extension has been blacklisted.
+ REASON_PROFILE_SHUTDOWN, // Profile is being shut down.
};
Reason reason;